==> OpenOLAP_V1.0.zip: OpenOLAP/src/viewer/target/spread/js/toolBar.js <==

//  c[o[X^C֘A萔 
	var sOffBackColor = "#F4F4FF";
	var sOffTextColor = "menutext"
	var sOffBorderColor = "#F4F4FF";
	var sOffPadding = "1px 1px 1px 1px";

	var sOverBackColor = "lavender";
	var sOverTextColor = "menutext"
	var sOverBorderColor = "white #AAAAAA #AAAAAA white";
	var sOverPadding = "1px 1px 1px 1px";

	var sDownBackColor = "window"
	var sDownTextColor = "menutext"
	var sDownBorderColor = "#AAAAAA white white #AAAAAA";
	var sDownPadding = "2px 0px 0px 2px";

//  c[o[̃X^C֐ 

var selectedButton = null; // v_Ej[\̃{^

// J[pbg\{^̑IԃX^CNA
function clearColorButton() {
	var palletButton = document.all("tblColorBtn");
	palletButton.style.backgroundColor = sOffBackColor;
	palletButton.style.borderColor = sOffBorderColor;
	palletButton.style.color = sOffTextColor;
	if ( palletButton.id == "tblColorBtn" ) {
		document.all("divPallet").style.display='none'
	}
}

// j[{^Ƀ}EXI[o[ꂽX^CύX
function menu_button_over(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	eButtonTable.style.borderColor = sOverBorderColor;
}

// }EX|C^{^痣ꂽX^CύX
function menu_button_out(eButton) {

	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	// X^CύX
	eButtonTable.style.backgroundColor = sOffBackColor;
	eButtonTable.style.borderColor = sOffBorderColor;
	eButtonTable.style.color = sOffTextColor;
}

// j[{^}EX_Eꂽ
function menu_button_down(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	eButtonTable.style.borderColor = sDownBorderColor;
}

// j[{^NbNꂽ
function menu_button_click(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	// J[pbg\{^NbNꂽ
	if ( eButtonTable.id == "tblColorBtn" ) {
		showColorPallet(eButtonTable);
	}
}

// ============== F֘A ==================================================

// J[pbg\
function showColorPallet(eButtonTable) {
		selectedButton = eButtonTable;							// {^IԂɐݒ
		document.all("divPallet").style.display='block';		// pbg\
		document.attachEvent('onmouseup', mouse_up_for_menu);	// mouse_up_for_menuCxgdocumentɃZbg
}

// document̃}EXAbvŃJ[{^̃X^CApbg\ɂ
function mouse_up_for_menu() {
	selectedButton = null;							// IԂ̃{^
	clearColorButton();								// J[{^̏NA
	document.all("divPallet").style.display='none';	// pbg̔\
	document.detachEvent('onmouseup', mouse_up_for_menu);	// Cxg̃NA
}

// J[pbgŐFIꂽ
function subWindowButton_up(eButton) {
	if ( eButton.parentNode.parentNode.parentNode.parentNode.id != "tblColorPallet" ) { return; }

	// Iς݂̃ZFt
	setColorToSelectedCell( eButton.colorStyle );

	// j[{^ɕ\̃C[WANbNꂽpbg̃C[WɕύX
	document.all("tblColorBtn").firstChild.firstChild.firstChild.firstChild.src = eButton.firstChild.firstChild.firstChild.firstChild.src;

}

// ============== ZN^֘A ==================================================

	// ZN^EChE Open
	function openSelector() {

//		window.open('Controller?action=displaySelecter','_blank','width=500px,height=550px,statusbar=no,toolbar=no');

//	[_ZN^
		var args = new Array();
		args[0] = window;
		args[1] = axesXMLData;
		var ret = showModalDialog('Controller?action=displaySelecter',args,'dialogHeight:550px;dialogWidth:500px;toolbar=no;status:no;');
	}

// ============== |[gCSV,ExcelGNX|[g ===============================

	//GNX|[g{^NbN
	function export_button_click() {

		// T[oւ̃ANZX󋵂ݒ(C[W𓮂)
		setLoadingStatus(true);

		// ݕ\Ăs/̏擾Ahiddenɕۑ
		// ieohŔ\ƂȂĂ郁o͊܂߂ȂBj
		setViewingColRowInfo();

		// F擾Ahiddenɕۑ
		setColorInfo();

		// T[o[֑M
		document.SpreadForm.action = "Controller?action=exportReport";
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();

	}

	// ݕ\Ăs/̏擾Ahiddenɕۑ
	function setViewingColRowInfo() {

		// dĂKeyO邽߂Dictionarygp
		var viewCol0KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewCol1KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewCol2KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow0KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow1KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow2KeyDict = new ActiveXObject("Scripting.Dictionary");

		var viewColIndexKey_hidden = "";
		var viewRowIndexKey_hidden = "";

		// sEwb_̕\SpreadIndexXg
		var colSpreadIndexArray = (new VBArray(viewingColSpreadIndexKeysDict.Keys())).toArray();
		var rowSpreadIndexArray = (new VBArray(viewingRowSpreadIndexKeysDict.Keys())).toArray();

		for ( var i = 0; i < colSpreadIndexArray.length; i++ ) {
			var colSpreadIndex = colSpreadIndexArray[i];
			var colKeyArray = viewingColSpreadIndexKeysDict.Item(colSpreadIndex);

			// KeyXg(COL)
			if ( !viewCol0KeyDict.Exists(colKeyArray[0]) ) {
				viewCol0KeyDict.Add(colKeyArray[0], 1);
			}
			if ( colKeyArray[1] != "" ) {
				if ( !viewCol1KeyDict.Exists(colKeyArray[1]) ) {
					viewCol1KeyDict.Add(colKeyArray[1], 1);
				}
			}
			if ( colKeyArray[2] != "" ) {
				if ( !viewCol2KeyDict.Exists(colKeyArray[2]) ) {
					viewCol2KeyDict.Add(colKeyArray[2], 1);
				}
			}

			// SpreadIndex,KeyXg(COL)
			if ( viewColIndexKey_hidden != "" ) {
				viewColIndexKey_hidden += ",";
			}
			viewColIndexKey_hidden += colSpreadIndex + ":" + colKeyArray.join(";");
		}

		for ( var i = 0; i < rowSpreadIndexArray.length; i++ ) {
			var rowSpreadIndex = rowSpreadIndexArray[i];
			var rowKeyArray = viewingRowSpreadIndexKeysDict.Item(rowSpreadIndex);

			// KeyXg(ROW)
			if ( !viewRow0KeyDict.Exists(rowKeyArray[0]) ) {
				viewRow0KeyDict.Add(rowKeyArray[0], 1);
			}
			if ( rowKeyArray[1] != "" ) {
				if ( !viewRow1KeyDict.Exists(rowKeyArray[1]) ) {
					viewRow1KeyDict.Add(rowKeyArray[1], 1);
				}
			}
			if ( rowKeyArray[2] != "" ) {
				if ( !viewRow2KeyDict.Exists(rowKeyArray[2]) ) {
					viewRow2KeyDict.Add(rowKeyArray[2], 1);
				}
			}

			// SpreadIndex,KeyXg(ROW)
			if ( viewRowIndexKey_hidden != "" ) {
				viewRowIndexKey_hidden += ",";
			}
			viewRowIndexKey_hidden += rowSpreadIndex + ":" + rowKeyArray.join(";");
		}


		// Dictionary KeyXg擾
		var viewColKeyArray = new Array(3);
			viewColKeyArray[0] = (new VBArray(viewCol0KeyDict.Keys())).toArray();
			viewColKeyArray[1] = (new VBArray(viewCol1KeyDict.Keys())).toArray();
			viewColKeyArray[2] = (new VBArray(viewCol2KeyDict.Keys())).toArray();

		var viewRowKeyArray = new Array(3);
			viewRowKeyArray[0] = (new VBArray(viewRow0KeyDict.Keys())).toArray();
			viewRowKeyArray[1] = (new VBArray(viewRow1KeyDict.Keys())).toArray();
			viewRowKeyArray[2] = (new VBArray(viewRow2KeyDict.Keys())).toArray();

		// hidden ֓o^
		document.SpreadForm.viewCol0KeyList_hidden.value  = viewColKeyArray[0];
		document.SpreadForm.viewCol1KeyList_hidden.value  = viewColKeyArray[1];
		document.SpreadForm.viewCol2KeyList_hidden.value  = viewColKeyArray[2];
		document.SpreadForm.viewRow0KeyList_hidden.value  = viewRowKeyArray[0];
		document.SpreadForm.viewRow1KeyList_hidden.value  = viewRowKeyArray[1];
		document.SpreadForm.viewRow2KeyList_hidden.value  = viewRowKeyArray[2];

		document.SpreadForm.viewColIndexKey_hidden.value = viewColIndexKey_hidden;
		document.SpreadForm.viewRowIndexKey_hidden.value = viewRowIndexKey_hidden;

	}

	// Fhiddenɐݒ
	function setColorInfo() {

		var colorIndexInfoArray = getColorIndexInfoArray();
		if ( colorIndexInfoArray != null ) {
			document.SpreadForm.colHdrColor.value = colorIndexInfoArray[0];	// wb_[̐F
			document.SpreadForm.rowHdrColor.value = colorIndexInfoArray[1];	// swb_[̐F
			document.SpreadForm.dataHdrColor.value = colorIndexInfoArray[2];// f[^e[u̐F

//alert("colValue:" + document.SpreadForm.colHdrColor.value);
//alert("rowValue:" + document.SpreadForm.rowHdrColor.value);
//alert("pageValue:" + document.SpreadForm.dataHdrColor.value);

		}
	}

// ============== |[gۑ ================================================

	// |[gۑ
	function saveReportInfo(reportName, folderID) {

		// T[oւ̃ANZX󋵂ݒ(C[W𓮂)
		setLoadingStatus(true);

		// hۑ
		var axes = axesXMLData.selectNodes("/root/Axes/Members");
		for ( var i = 0; i < axes.length; i++ ) {
			var drillStatString = "";
			var axisID = axes[i].getAttributeNode("id").value;
			var members = axes[i].selectNodes(".//Member");
//alert(members.length);

			for ( var j = 0; j < members.length; j++ ) {
				var thisNode = members[j];
				var uName = thisNode.selectSingleNode("UName").text;
				var isDrilled = thisNode.selectSingleNode("isDrilled").text;
				if ( isDrilled == "true" ) {
					isDrilled = "1";
				} else {
					isDrilled = "0";
				}
				if(drillStatString != "" ) {
					drillStatString += ",";
				}
				drillStatString += uName + ":" + isDrilled;
			}

			document.getElementById("dim" + axisID).value = drillStatString;
		}


		// F擾
		var colorInfoArray = getColorArray();

		// Fhiddenɓo^
		if( colorInfoArray != null ) {
			document.SpreadForm.hdrColorInfo.value = colorInfoArray[0];	// wb_[̐F
			document.SpreadForm.dtColorInfo.value  = colorInfoArray[1];	// f[^e[u̐F
		}

		// T[o[֑M
		document.SpreadForm.action = "Controller?action=saveClientReportStatus&reportName=" + reportName + "&folderID=" + folderID;
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();

	}

// ============== OAEg ================================================

	// OAEgs
	function logout() {

		if ( showConfirm("CFM1") ) {
			document.SpreadForm.action = "Controller?action=logout";
			document.SpreadForm.target = "_top";
			document.SpreadForm.submit();
		}

	}

==> OpenOLAP_V1.0.1.zip: OpenOLAP/src/viewer/target/spread/js/toolBar.js <==

//  c[o[X^C֘A萔 
	var sOffBackColor = "#F4F4FF";
	var sOffTextColor = "menutext"
	var sOffBorderColor = "#F4F4FF";
	var sOffPadding = "1px 1px 1px 1px";

	var sOverBackColor = "lavender";
	var sOverTextColor = "menutext"
	var sOverBorderColor = "white #AAAAAA #AAAAAA white";
	var sOverPadding = "1px 1px 1px 1px";

	var sDownBackColor = "window"
	var sDownTextColor = "menutext"
	var sDownBorderColor = "#AAAAAA white white #AAAAAA";
	var sDownPadding = "2px 0px 0px 2px";

//  c[o[̃X^C֐ 

var selectedButton = null; // v_Ej[\̃{^

// J[pbg\{^̑IԃX^CNA
function clearColorButton() {
	var palletButton = document.all("tblColorBtn");
	palletButton.style.backgroundColor = sOffBackColor;
	palletButton.style.borderColor = sOffBorderColor;
	palletButton.style.color = sOffTextColor;
	if ( palletButton.id == "tblColorBtn" ) {
		document.all("divPallet").style.display='none'
	}
}

// j[{^Ƀ}EXI[o[ꂽX^CύX
function menu_button_over(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	eButtonTable.style.borderColor = sOverBorderColor;
}

// }EX|C^{^痣ꂽX^CύX
function menu_button_out(eButton) {

	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	// X^CύX
	eButtonTable.style.backgroundColor = sOffBackColor;
	eButtonTable.style.borderColor = sOffBorderColor;
	eButtonTable.style.color = sOffTextColor;
}

// j[{^}EX_Eꂽ
function menu_button_down(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	eButtonTable.style.borderColor = sDownBorderColor;
}

// j[{^NbNꂽ
function menu_button_click(eButton) {
	var eButtonTable = null;
		if ( eButton.tagName == "DIV" ) {
			eButtonTable = eButton.parentNode.parentNode.parentNode.parentNode;
		} else {
			return false;
		}

	// J[pbg\{^NbNꂽ
	if ( eButtonTable.id == "tblColorBtn" ) {
		showColorPallet(eButtonTable);
	}
}

// ============== F֘A ==================================================

// J[pbg\
function showColorPallet(eButtonTable) {
		selectedButton = eButtonTable;							// {^IԂɐݒ
		document.all("divPallet").style.display='block';		// pbg\
		document.attachEvent('onmouseup', mouse_up_for_menu);	// mouse_up_for_menuCxgdocumentɃZbg
}

// document̃}EXAbvŃJ[{^̃X^CApbg\ɂ
function mouse_up_for_menu() {
	selectedButton = null;							// IԂ̃{^
	clearColorButton();								// J[{^̏NA
	document.all("divPallet").style.display='none';	// pbg̔\
	document.detachEvent('onmouseup', mouse_up_for_menu);	// Cxg̃NA
}

// J[pbgŐFIꂽ
function subWindowButton_up(eButton) {
	if ( eButton.parentNode.parentNode.parentNode.parentNode.id != "tblColorPallet" ) { return; }

	// Iς݂̃ZFt
	setColorToSelectedCell( eButton.colorStyle );

	// j[{^ɕ\̃C[WANbNꂽpbg̃C[WɕύX
	document.all("tblColorBtn").firstChild.firstChild.firstChild.firstChild.src = eButton.firstChild.firstChild.firstChild.firstChild.src;

}

// ============== ZN^֘A ==================================================

	// ZN^EChE Open
	function openSelector() {

//		window.open('Controller?action=displaySelecter','_blank','width=500px,height=550px,statusbar=no,toolbar=no');

//	[_ZN^
		var args = new Array();
		args[0] = window;
		args[1] = axesXMLData;
		var ret = showModalDialog('Controller?action=displaySelecter',args,'dialogHeight:550px;dialogWidth:500px;toolbar=no;status:no;');
	}

// ============== |[g̃GNX|[g ===============================

	//GNX|[g{^NbN
	function export_button_click() {

		// T[oւ̃ANZX󋵂ݒ(C[W𓮂)
		setLoadingStatus(true);

		// ݕ\Ăs/̏擾Ahiddenɕۑ
		// ieohŔ\ƂȂĂ郁o͊܂߂ȂBj
		setViewingColRowInfo();

		// F擾Ahiddenɕۑ
		setColorInfo();

		// T[o[֑M
		document.SpreadForm.action = "Controller?action=exportReport";
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();

	}

	// ݕ\Ăs/̏擾Ahiddenɕۑ
	function setViewingColRowInfo() {

		// dĂKeyO邽߂Dictionarygp
		var viewCol0KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewCol1KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewCol2KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow0KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow1KeyDict = new ActiveXObject("Scripting.Dictionary");
		var viewRow2KeyDict = new ActiveXObject("Scripting.Dictionary");

		var viewColIndexKey_hidden = "";
		var viewRowIndexKey_hidden = "";

		// sEwb_̕\SpreadIndexXg
		var colSpreadIndexArray = (new VBArray(viewingColSpreadIndexKeysDict.Keys())).toArray();
		var rowSpreadIndexArray = (new VBArray(viewingRowSpreadIndexKeysDict.Keys())).toArray();

		for ( var i = 0; i < colSpreadIndexArray.length; i++ ) {
			var colSpreadIndex = colSpreadIndexArray[i];
			var colKeyArray = viewingColSpreadIndexKeysDict.Item(colSpreadIndex);

			// KeyXg(COL)
			if ( !viewCol0KeyDict.Exists(colKeyArray[0]) ) {
				viewCol0KeyDict.Add(colKeyArray[0], 1);
			}
			if ( colKeyArray[1] != "" ) {
				if ( !viewCol1KeyDict.Exists(colKeyArray[1]) ) {
					viewCol1KeyDict.Add(colKeyArray[1], 1);
				}
			}
			if ( colKeyArray[2] != "" ) {
				if ( !viewCol2KeyDict.Exists(colKeyArray[2]) ) {
					viewCol2KeyDict.Add(colKeyArray[2], 1);
				}
			}

			// SpreadIndex,KeyXg(COL)
			if ( viewColIndexKey_hidden != "" ) {
				viewColIndexKey_hidden += ",";
			}
			viewColIndexKey_hidden += colSpreadIndex + ":" + colKeyArray.join(";");
		}

		for ( var i = 0; i < rowSpreadIndexArray.length; i++ ) {
			var rowSpreadIndex = rowSpreadIndexArray[i];
			var rowKeyArray = viewingRowSpreadIndexKeysDict.Item(rowSpreadIndex);

			// KeyXg(ROW)
			if ( !viewRow0KeyDict.Exists(rowKeyArray[0]) ) {
				viewRow0KeyDict.Add(rowKeyArray[0], 1);
			}
			if ( rowKeyArray[1] != "" ) {
				if ( !viewRow1KeyDict.Exists(rowKeyArray[1]) ) {
					viewRow1KeyDict.Add(rowKeyArray[1], 1);
				}
			}
			if ( rowKeyArray[2] != "" ) {
				if ( !viewRow2KeyDict.Exists(rowKeyArray[2]) ) {
					viewRow2KeyDict.Add(rowKeyArray[2], 1);
				}
			}

			// SpreadIndex,KeyXg(ROW)
			if ( viewRowIndexKey_hidden != "" ) {
				viewRowIndexKey_hidden += ",";
			}
			viewRowIndexKey_hidden += rowSpreadIndex + ":" + rowKeyArray.join(";");
		}


		// Dictionary KeyXg擾
		var viewColKeyArray = new Array(3);
			viewColKeyArray[0] = (new VBArray(viewCol0KeyDict.Keys())).toArray();
			viewColKeyArray[1] = (new VBArray(viewCol1KeyDict.Keys())).toArray();
			viewColKeyArray[2] = (new VBArray(viewCol2KeyDict.Keys())).toArray();

		var viewRowKeyArray = new Array(3);
			viewRowKeyArray[0] = (new VBArray(viewRow0KeyDict.Keys())).toArray();
			viewRowKeyArray[1] = (new VBArray(viewRow1KeyDict.Keys())).toArray();
			viewRowKeyArray[2] = (new VBArray(viewRow2KeyDict.Keys())).toArray();

		// hidden ֓o^
		document.SpreadForm.viewCol0KeyList_hidden.value  = viewColKeyArray[0];
		document.SpreadForm.viewCol1KeyList_hidden.value  = viewColKeyArray[1];
		document.SpreadForm.viewCol2KeyList_hidden.value  = viewColKeyArray[2];
		document.SpreadForm.viewRow0KeyList_hidden.value  = viewRowKeyArray[0];
		document.SpreadForm.viewRow1KeyList_hidden.value  = viewRowKeyArray[1];
		document.SpreadForm.viewRow2KeyList_hidden.value  = viewRowKeyArray[2];

		document.SpreadForm.viewColIndexKey_hidden.value = viewColIndexKey_hidden;
		document.SpreadForm.viewRowIndexKey_hidden.value = viewRowIndexKey_hidden;

	}

	// Fhiddenɐݒ
	function setColorInfo() {

		var colorIndexInfoArray = getColorIndexInfoArray();
		if ( colorIndexInfoArray != null ) {
			document.SpreadForm.colHdrColor.value = colorIndexInfoArray[0];	// wb_[̐F
			document.SpreadForm.rowHdrColor.value = colorIndexInfoArray[1];	// swb_[̐F
			document.SpreadForm.dataHdrColor.value = colorIndexInfoArray[2];// f[^e[u̐F

//alert("colValue:" + document.SpreadForm.colHdrColor.value);
//alert("rowValue:" + document.SpreadForm.rowHdrColor.value);
//alert("pageValue:" + document.SpreadForm.dataHdrColor.value);

		}
	}

// ============== |[gۑ ================================================

	// |[gۑ
	function saveReportInfo(reportName, folderID) {

		// T[oւ̃ANZX󋵂ݒ(C[W𓮂)
		setLoadingStatus(true);

		// hۑ
		var axes = axesXMLData.selectNodes("/root/Axes/Members");
		for ( var i = 0; i < axes.length; i++ ) {
			var drillStatString = "";
			var axisID = axes[i].getAttributeNode("id").value;
			var members = axes[i].selectNodes(".//Member");
//alert(members.length);

			for ( var j = 0; j < members.length; j++ ) {
				var thisNode = members[j];
				var uName = thisNode.selectSingleNode("UName").text;
				var isDrilled = thisNode.selectSingleNode("isDrilled").text;
				if ( isDrilled == "true" ) {
					isDrilled = "1";
				} else {
					isDrilled = "0";
				}
				if(drillStatString != "" ) {
					drillStatString += ",";
				}
				drillStatString += uName + ":" + isDrilled;
			}

			document.getElementById("dim" + axisID).value = drillStatString;
		}


		// F擾
		var colorInfoArray = getColorArray();

		// Fhiddenɓo^
		if( colorInfoArray != null ) {
			document.SpreadForm.hdrColorInfo.value = colorInfoArray[0];	// wb_[̐F
			document.SpreadForm.dtColorInfo.value  = colorInfoArray[1];	// f[^e[u̐F
		}

		// T[o[֑M
		document.SpreadForm.action = "Controller?action=saveClientReportStatus&reportName=" + reportName + "&folderID=" + folderID;
		document.SpreadForm.target = "loadingStatus";
		document.SpreadForm.submit();

	}

// ============== OAEg ================================================

	// OAEgs
	function logout() {

		if ( showConfirm("CFM1") ) {
			document.SpreadForm.action = "Controller?action=logout";
			document.SpreadForm.target = "_top";
			document.SpreadForm.submit();
		}

	}
